@@ -651,7 +651,8 @@ class AuthProtocol(BaseAuthProtocol):
                 raise webob.exc.HTTPUnauthorized(
                     body=jsonutils.dumps(body),
                     headers=self._reject_auth_headers,
-                    content_type='application/json; charset=UTF-8')
+                    charset='UTF-8',
+                    content_type='application/json')
 
         if request.user_token_valid:
             request.set_user_headers(request.token_auth.user)
